Misc fixes and improvements for 2.5.6

1. Fix RCCL unit test
2. Add ROME detection and tuning
3. Change default P2P level
4. Fix search algorithm for XGMI
5. Remove explicit channel duplication with implicit by using half of link speed
6. Add collective trace support
7. Correct Intel Skylake CPU detection and bandwidth
8. Fix topo connect function
9. Disable GDR read and remove unreachable code
10. Disable LL128 kernels
11. Add tuning parameters
12. Use original clock64() implementation which returns RTC counter value
13. Print out timestamp of collective trace
14. Do not use struct ncclColl in kernel launch parameter
15. Fix abort handling and add tracing
17. Add __launch_bounds__ to kernel functions
18. Remove unused abortCount
19. Unset default MIN_NRINGS and MIN_NCHANNELS
20. Do not allocate shared memory when not using LL128 kernels
21. Correct time print out in tuning log


[ROCm/rccl commit: 1e55645d97]
Этот коммит содержится в:
Wenkai Du
2019-11-26 16:33:13 -08:00
родитель d7d4175df0
Коммит d2fbcfea02
20 изменённых файлов: 307 добавлений и 121 удалений
+1 -1
Просмотреть файл
@@ -23,7 +23,7 @@
/* Declare all collective operations */
#define DECL_COLL5(coll, op, dtype) \
extern __device__ __attribute__((noinline)) void NCCL_COLL_NAME(coll, op, dtype)(struct CollectiveArgs* args); \
extern __global__ void NCCL_KERN_NAME(coll, op, dtype)(struct ncclColl c); \
extern __global__ void NCCL_KERN_NAME(coll, op, dtype)(struct ncclDevComm* comm); \
#define DECL_COLL4(coll, op, dtype) \
DECL_COLL5(coll, op, dtype) \
+2 -2
Просмотреть файл
@@ -134,8 +134,8 @@ struct ncclComm {
int* intraCudaDevs;
int* intraCGMode; // Whether we can use CUDA9 CGMD or not
int* intraCC; // Only to check all have the same ComputeCap and disable CGMode if not
struct ncclColl args;
struct ncclColl* argsptr;
struct ncclDevComm* args;
struct ncclDevComm** argsptr;
// Global proxy thread
pthread_t proxyThread;
+28 -1
Просмотреть файл
@@ -207,7 +207,6 @@ struct ncclChannel {
int collFifoHead; // Only used by GPU
int collFifoTail; // Only used by CPU
uint32_t* abortCount;
uint32_t* sync;
};
int data[0x80];
@@ -255,6 +254,27 @@ struct ncclProf {
};
#endif
#ifdef ENABLE_COLLTRACE
typedef enum {
ncclCollTraceKernelLaunchType,
ncclCollTraceCollEndType,
ncclCollTraceAbortType
} ncclCollTraceDataType_t;
struct ncclCollTrace {
uint8_t type;
uint8_t bid;
int16_t funcIndex;
uint32_t data_0;
uint64_t timeStamp;
uint64_t opCount;
uint64_t data_1;
};
static_assert(sizeof(struct ncclCollTrace) == 8*sizeof(int), "ncclCollTrace must have a pow2 size");
#define COLLTRACE_NUM_ITEMS 1024
#endif
typedef enum {
ncclDevSuccess,
ncclDevAssertedMismatch,
@@ -276,6 +296,13 @@ struct ncclDevComm {
// Profiling counters
struct ncclProf* devProf;
#endif
#ifdef ENABLE_COLLTRACE
struct ncclCollTrace* collTrace;
uint32_t collTraceHead, *collTraceTail;
pthread_t collTraceThread;
bool collTraceExit;
#endif
};
#endif